@@ -1,10 +1,8 @@
 package MIDI::Simple::Drummer;
-BEGIN {
-  $MIDI::Simple::Drummer::AUTHORITY = 'cpan:GENE';
-}
+our $AUTHORITY = 'cpan:GENE';
 # ABSTRACT: An algorithmic MIDI drummer
 
-our $VERSION = '0.08';
+our $VERSION = '0.0801';
 
 use strict;
 use warnings;
@@ -584,7 +582,7 @@ MIDI::Simple::Drummer - An algorithmic MIDI drummer
 
 =head1 VERSION
 
-version 0.08
+version 0.0801
 
 =head1 SYNOPSIS
 
@@ -649,7 +647,7 @@ version 0.08
   }
   sub backbeat { # kick/snare
     my $self = shift;
-    $self->note($self->div_name, $self->rotate($_)) for 1 .. $self->beats;
+    $self->note($self->QUARTER, $self->rotate($_)) for 1 .. $self->beats;
   }
 
 =head1 DESCRIPTION
@@ -1115,7 +1113,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
