@@ -1,7 +1,5 @@
 package MIDI::Simple::Drummer::Jazz;
-BEGIN {
-  $MIDI::Simple::Drummer::Jazz::AUTHORITY = 'cpan:GENE';
-}
+our $AUTHORITY = 'cpan:GENE';
 our $VERSION = '0.02';
 use strict;
 use warnings;
@@ -145,7 +143,7 @@ MIDI::Simple::Drummer::Jazz
 
 =head1 VERSION
 
-version 0.08
+version 0.0801
 
 =head1 DESCRIPTION
 
@@ -182,7 +180,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
