@@ -1,7 +1,5 @@
 package MIDI::Simple::Drummer::Rock;
-BEGIN {
-  $MIDI::Simple::Drummer::Rock::AUTHORITY = 'cpan:GENE';
-}
+our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 use parent 'MIDI::Simple::Drummer';
@@ -293,7 +291,7 @@ MIDI::Simple::Drummer::Rock
 
 =head1 VERSION
 
-version 0.08
+version 0.0801
 
 =head1 DESCRIPTION
 
@@ -325,7 +323,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
