@@ -1,7 +1,5 @@
 package MIDI::Simple::Drummer::Rudiments;
-BEGIN {
-  $MIDI::Simple::Drummer::Rudiments::AUTHORITY = 'cpan:GENE';
-}
+our $AUTHORITY = 'cpan:GENE';
 
 our $VERSION = '0.04';
 
@@ -967,7 +965,7 @@ MIDI::Simple::Drummer::Rudiments
 
 =head1 VERSION
 
-version 0.08
+version 0.0801
 
 =head1 SYNOPSIS
 
@@ -1345,7 +1343,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
